@@ -17,9 +17,7 @@ OC.L10N.register(
     "SMTP Password" : "Contrasigno SMTP",
     "Go back" : "Retornar",
     "Cancel" : "Cancellar",
-    "Accounts" : "Accounts",
     "General" : "General",
-    "Keyboard shortcuts" : "Combinationes de claves",
     "Delete" : "Deler",
     "Search" : "Cercar",
     "Send" : "Inviar",
@@ -28,6 +26,7 @@ OC.L10N.register(
     "Confirm" : "Confirmar",
     "Favorite" : "Favorite",
     "Back" : "Retro",
+    "Attendees" : "Participantes",
     "Description" : "Description",
     "Create" : "Crear",
     "Select" : "Selectionar",
@@ -35,6 +34,7 @@ OC.L10N.register(
     "Accept" : "Acceptar",
     "Decline" : "Refusar",
     "Today" : "Hodie",
+    "Favorites" : "Favoritos",
     "Other" : "Altere",
     "Unnamed" : "Non nominate",
     "Choose a folder to store the attachment in" : "Selectiona un dossier pro salveguardar le attachamento",
@@ -51,8 +51,13 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Etiquettas",
     "Custom" : "Personalisate",
+    "Deleted" : "Delite",
+    "Help" : "Adjuta",
     "matches" : "corresponde",
+    "Actions" : "Actiones",
     "Priority" : "Prioritate",
+    "delete" : "deler",
+    "Edit" : "Modificar",
     "Reset" : "Re-fixar",
     "User" : "User",
     "Host" : "Hospite",
@@ -62,10 +67,8 @@ OC.L10N.register(
     "Shared" : "Compartite",
     "Shares" : "Compartimentos",
     "All" : "Tote",
-    "Favorites" : "Favoritos",
     "All inboxes" : "Tote cassas de entrata",
     "Could not load {tag}{name}{endtag}" : "Impossibile cargar {tag}{name}{endtag}",
-    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}",
-    "Actions" : "Actiones"
+    "There was a problem loading {tag}{name}{endtag}" : "Un problema occurreva durante le carga de {tag}{name}{endtag}"
 },
 "nplurals=2; plural=(n != 1);");
